@@ -23,9 +23,10 @@ enum { KM_FEEDLIST = 1 << 0,
 	KM_DIRBROWSER = 1 << 10,
 	KM_SYSKEYS = 1 << 11,
 	KM_INTERNAL = 1 << 12,
+	KM_SEARCHRESULTSLIST = 1 << 13,
 	KM_NEWSBOAT = KM_FEEDLIST | KM_FILEBROWSER | KM_HELP | KM_ARTICLELIST |
 		KM_ARTICLE | KM_TAGSELECT | KM_FILTERSELECT | KM_URLVIEW |
-		KM_DIALOGS | KM_DIRBROWSER,
+		KM_DIALOGS | KM_DIRBROWSER | KM_SEARCHRESULTSLIST,
 	KM_BOTH = KM_NEWSBOAT | KM_PODBOAT
 };
 
@@ -92,6 +93,7 @@ enum Operation {
 	OP_SORT,
 	OP_REVSORT,
 	OP_NB_MAX,
+	OP_PREVSEARCHRESULTS,
 
 	// podboat-specific operations:
 	OP_PB_MIN = 1000,
