@@ -1,20 +1,22 @@
 #include "cliargsparser.h"
 
-#include <getopt.h>
 #include <cstdlib>
 
-#include "globals.h"
-#include "ruststring.h"
-#include "strprintf.h"
-
 namespace newsboat {
 
 
-rust::Vec<rust::String> argv_to_rust_args(int argc, char* argv[])
+rust::Vec<cliargsparser::bridged::BytesVec> argv_to_rust_args(int argc, char* argv[])
 {
-	rust::Vec<rust::String> args;
+	rust::Vec<cliargsparser::bridged::BytesVec> args;
+	args.reserve(argc);
 	for (int i = 0; i < argc; ++i) {
-		args.push_back(argv[i]);
+		cliargsparser::bridged::BytesVec arg;
+		rust::Vec<uint8_t> data;
+		for (auto j = 0; argv[i][j] != '\0'; ++j) {
+			data.push_back(argv[i][j]);
+		}
+		arg.data = std::move(data);
+		args.push_back(arg);
 	}
 	return args;
 }
@@ -178,9 +180,9 @@ nonstd::optional<Level> CliArgsParser::log_level() const
 	return nonstd::nullopt;
 }
 
-void* CliArgsParser::get_rust_pointer() const
+const cliargsparser::bridged::CliArgsParser& CliArgsParser::get_rust_ref() const
 {
-	return (void*)&*rs_object;
+	return *rs_object;
 }
 
 } // namespace newsboat
