@@ -46,6 +46,7 @@ ConfigContainer::ConfigContainer()
 	{"cleanup-on-quit", ConfigData("yes", ConfigDataType::BOOL)},
 	{"confirm-delete-all-articles", ConfigData("yes", ConfigDataType::BOOL)},
 	{"confirm-mark-all-feeds-read", ConfigData("yes", ConfigDataType::BOOL)},
+	{"confirm-mark-feed-read", ConfigData("yes", ConfigDataType::BOOL)},
 	{"confirm-exit", ConfigData("no", ConfigDataType::BOOL)},
 	{"cookie-cache", ConfigData("", ConfigDataType::PATH)},
 	{"datetime-format", ConfigData("%b %d", ConfigDataType::STR)},
@@ -261,6 +262,7 @@ ConfigContainer::ConfigContainer()
 	{"ocnews-flag-star", ConfigData("", ConfigDataType::STR)},
 	{"ocnews-url", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-login", ConfigData("", ConfigDataType::STR)},
+	{"miniflux-min-items", ConfigData("100", ConfigDataType::INT)},
 	{"miniflux-password", ConfigData("", ConfigDataType::STR)},
 	{"miniflux-passwordfile", ConfigData("", ConfigDataType::PATH)},
 	{"miniflux-passwordeval", ConfigData("", ConfigDataType::STR)},
@@ -310,7 +312,7 @@ ConfigContainer::ConfigContainer()
 			ConfigDataType::STR)},
 	{
 		"searchresult-title-format",
-		ConfigData(_("%N %V - Search results (%u unread, %t total)%?F? matching filter '%F'&?"),
+		ConfigData(_("%N %V - Search results for '%s' (%u unread, %t total)%?F? matching filter '%F'&?"),
 			ConfigDataType::STR)},
 	{
 		"selectfilter-title-format",
