@@ -3,6 +3,7 @@
 #include <cassert>
 #include <cinttypes>
 #include <cstdio>
+#include <cstring>
 #include <langinfo.h>
 #include <sstream>
 #include <string>
@@ -12,6 +13,8 @@
 #include "controller.h"
 #include "dbexception.h"
 #include "fmtstrformatter.h"
+#include "formaction.h"
+#include "itemutils.h"
 #include "logger.h"
 #include "matcherexception.h"
 #include "rssfeed.h"
@@ -29,14 +32,13 @@ ItemListFormAction::ItemListFormAction(View* vv,
 	ConfigContainer* cfg,
 	RegexManager& r)
 	: ListFormAction(vv, formstr, "items", cfg)
-	, pos(0)
+	, old_itempos(-1)
 	, apply_filter(false)
-	, show_searchresult(false)
+	, pos(0)
 	, set_filterpos(false)
 	, filterpos(0)
 	, rxman(r)
 	, old_width(0)
-	, old_itempos(-1)
 	, invalidation_mode(InvalidationMode::NONE)
 	, listfmt(&rxman, "articlelist")
 	, rsscache(cc)
@@ -70,8 +72,7 @@ bool ItemListFormAction::process_operation(Operation op,
 			// that
 			old_itempos = itempos;
 			v->push_itemview(feed,
-				visible_items[itempos].first->guid(),
-				show_searchresult ? search_phrase : "");
+				visible_items[itempos].first->guid());
 			invalidate(itempos);
 		} else {
 			v->get_statusline().show_error(
@@ -333,7 +334,6 @@ bool ItemListFormAction::process_operation(Operation op,
 					this->start_bookmark_qna(
 						visible_items[itempos].first->title(),
 						visible_items[itempos].first->link(),
-						"",
 						feed->title());
 				}
 			}
@@ -396,15 +396,9 @@ bool ItemListFormAction::process_operation(Operation op,
 		v->push_help();
 		break;
 	case OP_RELOAD:
-		if (!show_searchresult) {
-			LOG(Level::INFO,
-				"ItemListFormAction: reloading current feed");
-			v->get_ctrl()->get_reloader()->reload(pos);
-			invalidate_list();
-		} else {
-			v->get_statusline().show_error(
-				_("Error: you can't reload search results."));
-		}
+		LOG(Level::INFO, "ItemListFormAction: reloading current feed");
+		v->get_ctrl()->get_reloader()->reload(pos);
+		invalidate_list();
 		break;
 	case OP_QUIT:
 		LOG(Level::INFO, "ItemListFormAction: quitting");
@@ -482,56 +476,61 @@ bool ItemListFormAction::process_operation(Operation op,
 		}
 		break;
 	case OP_MARKFEEDREAD:
-		LOG(Level::INFO, "ItemListFormAction: marking feed read");
-		try {
-			const auto message_lifetime = v->get_statusline().show_message_until_finished(
-					_("Marking feed read..."));
+		if (!cfg->get_configvalue_as_bool(
+				"confirm-mark-feed-read") ||
+			v->confirm(_("Do you really want to mark this feed as read (y:Yes n:No)? "),
+				_("yn")) == *_("y")) {
+			LOG(Level::INFO, "ItemListFormAction: marking feed read");
+			try {
+				const auto message_lifetime = v->get_statusline().show_message_until_finished(
+						_("Marking feed read..."));
 
-			std::vector<std::string> guids;
-			for (const auto& item : visible_items) {
-				const std::string guid = item.first->guid();
-				guids.push_back(guid);
-			}
-			rsscache->mark_items_read_by_guid(guids);
-
-			if (apply_filter) {
-				// We're only viewing a subset of items, so mark them off one by one.
-				v->get_ctrl()->mark_all_read(guids);
-			} else {
-				v->get_ctrl()->mark_all_read(pos);
-			}
-
-			if (visible_items.size() > 0) {
-				std::lock_guard<std::mutex> lock(feed->item_mutex);
-				bool notify = visible_items[0].first->feedurl() != feed->rssurl();
+				std::vector<std::string> guids;
 				for (const auto& item : visible_items) {
-					item.first->set_unread_nowrite_notify(false, notify);
+					const std::string guid = item.first->guid();
+					guids.push_back(guid);
 				}
-			}
-			if (cfg->get_configvalue_as_bool("markfeedread-jumps-to-next-unread")) {
-				process_operation(OP_NEXTUNREAD);
-			} else { // reposition to first/last item
-				std::string sortorder =
-					cfg->get_configvalue("article-sort-order");
+				rsscache->mark_items_read_by_guid(guids);
 
-				if (sortorder == "date-desc") {
-					LOG(Level::DEBUG,
-						"ItemListFormAction:: "
-						"reset itempos to last");
-					list.set_position(visible_items.size() - 1);
+				if (apply_filter) {
+					// We're only viewing a subset of items, so mark them off one by one.
+					v->get_ctrl()->mark_all_read(guids);
+				} else {
+					v->get_ctrl()->mark_all_read(pos);
 				}
-				if (sortorder == "date-asc") {
-					LOG(Level::DEBUG,
-						"ItemListFormAction:: "
-						"reset itempos to first");
-					list.set_position(0);
+
+				if (visible_items.size() > 0) {
+					std::lock_guard<std::mutex> lock(feed->item_mutex);
+					bool notify = visible_items[0].first->feedurl() != feed->rssurl();
+					for (const auto& item : visible_items) {
+						item.first->set_unread_nowrite_notify(false, notify);
+					}
 				}
+				if (cfg->get_configvalue_as_bool("markfeedread-jumps-to-next-unread")) {
+					process_operation(OP_NEXTUNREAD);
+				} else { // reposition to first/last item
+					std::string sortorder =
+						cfg->get_configvalue("article-sort-order");
+
+					if (sortorder == "date-desc") {
+						LOG(Level::DEBUG,
+							"ItemListFormAction:: "
+							"reset itempos to last");
+						list.set_position(visible_items.size() - 1);
+					}
+					if (sortorder == "date-asc") {
+						LOG(Level::DEBUG,
+							"ItemListFormAction:: "
+							"reset itempos to first");
+						list.set_position(0);
+					}
+				}
+				invalidate_list();
+			} catch (const DbException& e) {
+				v->get_statusline().show_error(strprintf::fmt(
+						_("Error: couldn't mark feed read: %s"),
+						e.what()));
 			}
-			invalidate_list();
-		} catch (const DbException& e) {
-			v->get_statusline().show_error(strprintf::fmt(
-					_("Error: couldn't mark feed read: %s"),
-					e.what()));
 		}
 		break;
 	case OP_MARKALLABOVEASREAD: {
@@ -754,6 +753,15 @@ bool ItemListFormAction::process_operation(Operation op,
 		}
 	}
 	break;
+	case OP_ENQUEUE:
+		if (!visible_items.empty() && itempos < visible_items.size()) {
+			const auto item = visible_items[itempos].first;
+			return enqueue_item_enclosure(item, feed, *v, *rsscache);
+		} else {
+			v->get_statusline().show_error(_("No item selected!"));
+			return false;
+		}
+		break;
 	default:
 		ListFormAction::process_operation(op, automatic, args);
 		break;
@@ -910,10 +918,6 @@ void ItemListFormAction::qna_start_search()
 	std::shared_ptr<RssFeed> search_dummy_feed(new RssFeed(rsscache, ""));
 	search_dummy_feed->set_search_feed(true);
 	search_dummy_feed->add_items(items);
-
-	if (show_searchresult) {
-		v->pop_current_formaction();
-	}
 	v->push_searchresult(search_dummy_feed, searchphrase);
 }
 
@@ -1081,6 +1085,7 @@ std::string ItemListFormAction::item2formatted_line(const ItemPtrPosPair& item,
 	fmt.register_fmt('n', item.first->unread() ? "N" : " ");
 	fmt.register_fmt('d', item.first->deleted() ? "D" : " ");
 	fmt.register_fmt('F', item.first->flags());
+	fmt.register_fmt('e', item.first->enclosure_url());
 
 	using namespace std::chrono;
 	const auto article_time_point = system_clock::from_time_t(
@@ -1169,16 +1174,11 @@ void ItemListFormAction::init()
 	invalidate_list();
 }
 
-void ItemListFormAction::set_head(const std::string& s,
+FmtStrFormatter ItemListFormAction::setup_head_formatter(const std::string& s,
 	unsigned int unread,
 	unsigned int total,
 	const std::string& url)
 {
-	/*
-	 * Since the ItemListFormAction is also used to display search results,
-	 * we always need to set the right title
-	 */
-	std::string title;
 	FmtStrFormatter fmt;
 
 	fmt.register_fmt('N', PROGRAM_NAME);
@@ -1195,16 +1195,22 @@ void ItemListFormAction::set_head(const std::string& s,
 
 	fmt.register_fmt('F', apply_filter ? matcher.get_expression() : "");
 
+	return fmt;
+}
+
+void ItemListFormAction::set_head(const std::string& s,
+	unsigned int unread,
+	unsigned int total,
+	const std::string& url)
+{
+	std::string title;
+
+	FmtStrFormatter fmt = setup_head_formatter(s, unread, total, url);
+
 	const unsigned int width = utils::to_u(f.get("title:w"));
-	if (!show_searchresult) {
-		title = fmt.do_format(
-				cfg->get_configvalue("articlelist-title-format"),
-				width);
-	} else {
-		title = fmt.do_format(
-				cfg->get_configvalue("searchresult-title-format"),
-				width);
-	}
+	title = fmt.do_format(
+			cfg->get_configvalue("articlelist-title-format"),
+			width);
 	set_value("head", title);
 }
 
@@ -1356,28 +1362,15 @@ void ItemListFormAction::handle_cmdline(const std::string& cmd)
 	if (1 == sscanf(cmd.c_str(), "%u", &idx)) {
 		handle_cmdline_num(idx);
 	} else {
-		std::vector<std::string> tokens = utils::tokenize_quoted(cmd);
-		if (tokens.empty()) {
-			return;
-		}
-		if (tokens[0] == "save") {
-			if (tokens.size() < 2) {
-				v->get_statusline().show_error(_("Error: no filename provided"));
-				return;
+		const auto command = FormAction::parse_command(cmd);
+		switch (command.type) {
+		case CommandType::SAVE:
+			if (!command.args.empty()) {
+				handle_save(command.args);
 			}
-			if (visible_items.empty()) {
-				v->get_statusline().show_error(_("Error: no item selected!"));
-				return;
-			}
-			const std::string filename = utils::resolve_tilde(tokens[1]);
-			const unsigned int itempos = list.get_position();
-			LOG(Level::INFO,
-				"ItemListFormAction::handle_cmdline: saving item at pos `%u' to `%s'",
-				itempos,
-				filename);
-			save_article(filename, visible_items[itempos].first);
-		} else {
-			FormAction::handle_cmdline(cmd);
+			break;
+		default:
+			FormAction::handle_parsed_command(command);
 		}
 	}
 }
@@ -1427,6 +1420,25 @@ void ItemListFormAction::save_article(const std::string& filename,
 	}
 }
 
+void ItemListFormAction::handle_save(const std::vector<std::string>& cmd_args)
+{
+	if (cmd_args.size() < 1) {
+		v->get_statusline().show_error(_("Error: no filename provided"));
+		return;
+	}
+	if (visible_items.empty()) {
+		v->get_statusline().show_error(_("Error: no item selected!"));
+		return;
+	}
+	const std::string filename = utils::resolve_tilde(cmd_args.front());
+	const unsigned int itempos = list.get_position();
+	LOG(Level::INFO,
+		"ItemListFormAction::handle_cmdline: saving item at pos `%u' to `%s'",
+		itempos,
+		filename);
+	save_article(filename, visible_items[itempos].first);
+}
+
 void ItemListFormAction::save_filterpos()
 {
 	const unsigned int i = list.get_position();
@@ -1495,19 +1507,15 @@ void ItemListFormAction::set_feed(std::shared_ptr<RssFeed> fd)
 
 std::string ItemListFormAction::title()
 {
-	if (feed->rssurl() == "") {
-		return strprintf::fmt(_("Search Result - '%s'"), search_phrase);
+	if (feed->is_query_feed()) {
+		return strprintf::fmt(_("Query Feed - %s"),
+				feed->rssurl().substr(
+					6, feed->rssurl().length() - 6));
 	} else {
-		if (feed->is_query_feed()) {
-			return strprintf::fmt(_("Query Feed - %s"),
-					feed->rssurl().substr(
-						6, feed->rssurl().length() - 6));
-		} else {
-			auto feedtitle = feed->title();
-			utils::remove_soft_hyphens(feedtitle);
-			return strprintf::fmt(
-					_("Article List - %s"), feedtitle);
-		}
+		auto feedtitle = feed->title();
+		utils::remove_soft_hyphens(feedtitle);
+		return strprintf::fmt(
+				_("Article List - %s"), feedtitle);
 	}
 }
 
