@@ -1,4 +1,5 @@
 #include "utils.h"
+#include <iostream>
 
 #include <algorithm>
 #include <cinttypes>
@@ -27,9 +28,9 @@
 #include <unordered_set>
 
 #include "config.h"
+#include "curlhandle.h"
 #include "htmlrenderer.h"
 #include "logger.h"
-#include "ruststring.h"
 #include "strprintf.h"
 
 #if HAVE_GCRYPT
@@ -48,37 +49,6 @@ using HTTPMethod = newsboat::utils::HTTPMethod;
 
 namespace newsboat {
 
-namespace utils {
-void append_escapes(std::string& str, char c)
-{
-	switch (c) {
-	case 'n':
-		str.append("\n");
-		break;
-	case 'r':
-		str.append("\r");
-		break;
-	case 't':
-		str.append("\t");
-		break;
-	case '"':
-		str.append("\"");
-		break;
-	// escaped backticks are passed through, still escaped. We un-escape
-	// them in ConfigParser::evaluate_backticks
-	case '`':
-		str.append("\\`");
-		break;
-	case '\\':
-		str.append("\\");
-		break;
-	default:
-		str.push_back(c);
-		break;
-	}
-}
-}
-
 std::string utils::strip_comments(const std::string& line)
 {
 	return std::string(utils::bridged::strip_comments(line));
@@ -87,86 +57,26 @@ std::string utils::strip_comments(const std::string& line)
 std::vector<std::string> utils::tokenize_quoted(const std::string& str,
 	std::string delimiters)
 {
-	/*
-	 * This function tokenizes strings, obeying quotes and throwing away
-	 * comments that start with a '#'.
-	 *
-	 * e.g. line: foo bar "foo bar" "a test"
-	 * is parsed to 4 elements:
-	 * 	[0]: foo
-	 * 	[1]: bar
-	 * 	[2]: foo bar
-	 * 	[3]: a test
-	 *
-	 * e.g. line: yes great "x\ny" # comment
-	 * is parsed to 3 elements:
-	 * 	[0]: yes
-	 * 	[1]: great
-	 * 	[2]: x
-	 * 	y
-	 *
-	 * 	\", \r, \n, and \t are replaced with the literals that you
-	 * know from C/C++ strings.
-	 *
-	 */
-	std::vector<std::string> tokens;
-	std::string remaining = str;
-	while (!remaining.empty()) {
-		auto token = extract_token_quoted(remaining, delimiters);
-		if (token.has_value()) {
-			tokens.push_back(token.value());
-		}
-	}
+	const auto tokens = utils::bridged::tokenize_quoted(str, delimiters);
 
-	return tokens;
+	std::vector<std::string> result;
+	for (const auto& token : tokens) {
+		result.push_back(std::string(token));
+	}
+	return result;
 }
 
 nonstd::optional<std::string> utils::extract_token_quoted(std::string& str,
 	std::string delimiters)
 {
-	auto first_non_delimiter = str.find_first_not_of(delimiters, 0);
-	if (first_non_delimiter == std::string::npos) {
-		str = "";
-		return {};
+	rust::String remaining = str;
+	rust::String token;
+	if (utils::bridged::extract_token_quoted(remaining, delimiters, token)) {
+		str = std::string(remaining);
+		return std::string(token);
 	}
-	str = str.substr(first_non_delimiter);
-
-	if (str[0] == '#') { // stop as soon as we find a comment
-		str = "";
-		return {};
-	}
-
-	std::string token;
-	if (str[0] == '"') {
-		std::string::size_type pos = 1;
-		while (pos < str.length()) {
-			if (str[pos] == '"') {
-				// We've reached the end of this quoted token.
-				++pos;
-				break;
-			} else if (str[pos] == '\\') {
-				pos += 1;
-				if (pos < str.length()) {
-					append_escapes(token, str[pos]);
-					pos += 1;
-				}
-			} else {
-				token.push_back(str[pos]);
-				++pos;
-			}
-		}
-		str = str.substr(pos);
-	} else {
-		auto end_of_token = str.find_first_of(delimiters);
-		token = str.substr(0, end_of_token);
-		if (end_of_token == std::string::npos) {
-			str = "";
-		} else {
-			str = str.substr(end_of_token);
-		}
-	}
-
-	return token;
+	str = std::string(remaining);
+	return {};
 }
 
 std::vector<std::string> utils::tokenize(const std::string& str,
@@ -315,44 +225,48 @@ std::string utils::retrieve_url(const std::string& url,
 	ConfigContainer* cfgcont,
 	const std::string& authinfo,
 	const std::string* body,
-	const HTTPMethod method, /* = GET */
-	CURL* cached_handle)
+	const HTTPMethod method /* = GET */)
+{
+	CurlHandle handle;
+	return retrieve_url(url, handle, cfgcont, authinfo, body, method);
+}
+
+std::string utils::retrieve_url(const std::string& url,
+	CurlHandle& easyhandle,
+	ConfigContainer* cfgcont,
+	const std::string& authinfo,
+	const std::string* body,
+	const HTTPMethod method /* = GET */)
 {
 	std::string buf;
 
-	CURL* easyhandle;
-	if (cached_handle) {
-		easyhandle = cached_handle;
-	} else {
-		easyhandle = curl_easy_init();
-	}
 	set_common_curl_options(easyhandle, cfgcont);
-	curl_easy_setopt(easyhandle, CURLOPT_URL, url.c_str());
-	curl_easy_setopt(easyhandle, CURLOPT_WRITEFUNCTION, my_write_data);
-	curl_easy_setopt(easyhandle, CURLOPT_WRITEDATA, &buf);
+	curl_easy_setopt(easyhandle.ptr(), CURLOPT_URL, url.c_str());
+	curl_easy_setopt(easyhandle.ptr(), CURLOPT_WRITEFUNCTION, my_write_data);
+	curl_easy_setopt(easyhandle.ptr(), CURLOPT_WRITEDATA, &buf);
 
 	switch (method) {
 	case HTTPMethod::GET:
 		break;
 	case HTTPMethod::POST:
-		curl_easy_setopt(easyhandle, CURLOPT_POST, 1);
+		curl_easy_setopt(easyhandle.ptr(), CURLOPT_POST, 1);
 		break;
 	case HTTPMethod::PUT:
 	case HTTPMethod::DELETE:
 		const std::string method_str = http_method_str(method);
-		curl_easy_setopt(easyhandle, CURLOPT_CUSTOMREQUEST, method_str.c_str());
+		curl_easy_setopt(easyhandle.ptr(), CURLOPT_CUSTOMREQUEST, method_str.c_str());
 		break;
 	}
 
 	if (body != nullptr) {
 		curl_easy_setopt(
-			easyhandle, CURLOPT_POSTFIELDS, body->c_str());
+			easyhandle.ptr(), CURLOPT_POSTFIELDS, body->c_str());
 	}
 
 	if (!authinfo.empty()) {
 		const auto auth_method = cfgcont->get_configvalue("http-auth-method");
-		curl_easy_setopt(easyhandle, CURLOPT_HTTPAUTH, get_auth_method(auth_method));
-		curl_easy_setopt(easyhandle, CURLOPT_USERPWD, authinfo.c_str());
+		curl_easy_setopt(easyhandle.ptr(), CURLOPT_HTTPAUTH, get_auth_method(auth_method));
+		curl_easy_setopt(easyhandle.ptr(), CURLOPT_USERPWD, authinfo.c_str());
 	}
 
 	// Error handling as per https://curl.se/libcurl/c/CURLOPT_ERRORBUFFER.html
@@ -360,10 +274,10 @@ std::string utils::retrieve_url(const std::string& url,
 	// Please note that we clobber CURLOPT_ERRORBUFFER here in case of cached handles
 	// Currently, this is the only place we do this, so this should be fine.
 	// There does not seem to be a way to query curlopts, so we cannot save the old errorbuf value here...
-	curl_easy_setopt(easyhandle, CURLOPT_ERRORBUFFER, errbuf);
+	curl_easy_setopt(easyhandle.ptr(), CURLOPT_ERRORBUFFER, errbuf);
 	errbuf[0] = '\0';
 
-	CURLcode res = curl_easy_perform(easyhandle);
+	CURLcode res = curl_easy_perform(easyhandle.ptr());
 
 	std::stringstream logprefix;
 	logprefix << "utils::retrieve_url(" << http_method_str(method) << " " << url << ")"
@@ -385,14 +299,10 @@ std::string utils::retrieve_url(const std::string& url,
 		LOG(Level::DEBUG, "%s: %s", logprefix.str(), buf);
 	}
 
-	if (!cached_handle) {
-		curl_easy_cleanup(easyhandle);
-	} else {
-		// Reset ERRORBUFFER: has to be valid for the whole lifetime of the handle
-		// NULL is the default value of this property according to man (3) CURLOPT_ERRORBUFFER
-		// See the clobbering note above.
-		curl_easy_setopt(easyhandle, CURLOPT_ERRORBUFFER, NULL);
-	}
+	// Reset ERRORBUFFER: has to be valid for the whole lifetime of the handle
+	// NULL is the default value of this property according to man (3) CURLOPT_ERRORBUFFER
+	// See the clobbering note above.
+	curl_easy_setopt(easyhandle.ptr(), CURLOPT_ERRORBUFFER, NULL);
 
 	return buf;
 }
@@ -590,24 +500,24 @@ std::string utils::quote_if_necessary(const std::string& str)
 	return std::string(utils::bridged::quote_if_necessary(str));
 }
 
-void utils::set_common_curl_options(CURL* handle, ConfigContainer* cfg)
+void utils::set_common_curl_options(CurlHandle& handle, ConfigContainer* cfg)
 {
 	if (cfg) {
 		if (cfg->get_configvalue_as_bool("use-proxy")) {
 			const std::string proxy = cfg->get_configvalue("proxy");
 			if (proxy != "")
 				curl_easy_setopt(
-					handle, CURLOPT_PROXY, proxy.c_str());
+					handle.ptr(), CURLOPT_PROXY, proxy.c_str());
 
 			const std::string proxyauth =
 				cfg->get_configvalue("proxy-auth");
 			const std::string proxyauthmethod =
 				cfg->get_configvalue("proxy-auth-method");
 			if (proxyauth != "") {
-				curl_easy_setopt(handle,
+				curl_easy_setopt(handle.ptr(),
 					CURLOPT_PROXYAUTH,
 					get_auth_method(proxyauthmethod));
-				curl_easy_setopt(handle,
+				curl_easy_setopt(handle.ptr(),
 					CURLOPT_PROXYUSERPWD,
 					proxyauth.c_str());
 			}
@@ -620,48 +530,48 @@ void utils::set_common_curl_options(CURL* handle, ConfigContainer* cfg)
 					"proxytype "
 					"= %s",
 					proxytype);
-				curl_easy_setopt(handle,
+				curl_easy_setopt(handle.ptr(),
 					CURLOPT_PROXYTYPE,
 					get_proxy_type(proxytype));
 			}
 		}
 
 		const std::string useragent = utils::get_useragent(cfg);
-		curl_easy_setopt(handle, CURLOPT_USERAGENT, useragent.c_str());
+		curl_easy_setopt(handle.ptr(), CURLOPT_USERAGENT, useragent.c_str());
 
 		const unsigned int dl_timeout =
 			cfg->get_configvalue_as_int("download-timeout");
-		curl_easy_setopt(handle, CURLOPT_TIMEOUT, dl_timeout);
+		curl_easy_setopt(handle.ptr(), CURLOPT_TIMEOUT, dl_timeout);
 
 		const std::string cookie_cache =
 			cfg->get_configvalue("cookie-cache");
 		if (cookie_cache != "") {
-			curl_easy_setopt(handle,
+			curl_easy_setopt(handle.ptr(),
 				CURLOPT_COOKIEFILE,
 				cookie_cache.c_str());
-			curl_easy_setopt(handle,
+			curl_easy_setopt(handle.ptr(),
 				CURLOPT_COOKIEJAR,
 				cookie_cache.c_str());
 		}
 
-		curl_easy_setopt(handle,
+		curl_easy_setopt(handle.ptr(),
 			CURLOPT_SSL_VERIFYHOST,
 			cfg->get_configvalue_as_bool("ssl-verifyhost") ? 2 : 0);
-		curl_easy_setopt(handle,
+		curl_easy_setopt(handle.ptr(),
 			CURLOPT_SSL_VERIFYPEER,
 			cfg->get_configvalue_as_bool("ssl-verifypeer"));
 	}
 
-	curl_easy_setopt(handle, CURLOPT_NOSIGNAL, 1);
-	curl_easy_setopt(handle, CURLOPT_ENCODING, "gzip, deflate");
+	curl_easy_setopt(handle.ptr(), CURLOPT_NOSIGNAL, 1);
+	curl_easy_setopt(handle.ptr(), CURLOPT_ENCODING, "gzip, deflate");
 
-	curl_easy_setopt(handle, CURLOPT_FOLLOWLOCATION, 1);
-	curl_easy_setopt(handle, CURLOPT_MAXREDIRS, 10);
-	curl_easy_setopt(handle, CURLOPT_FAILONERROR, 1);
+	curl_easy_setopt(handle.ptr(), CURLOPT_FOLLOWLOCATION, 1);
+	curl_easy_setopt(handle.ptr(), CURLOPT_MAXREDIRS, 10);
+	curl_easy_setopt(handle.ptr(), CURLOPT_FAILONERROR, 1);
 
 	const char* curl_ca_bundle = ::getenv("CURL_CA_BUNDLE");
 	if (curl_ca_bundle != nullptr) {
-		curl_easy_setopt(handle, CURLOPT_CAINFO, curl_ca_bundle);
+		curl_easy_setopt(handle.ptr(), CURLOPT_CAINFO, curl_ca_bundle);
 	}
 }
 
@@ -888,6 +798,11 @@ std::string utils::get_default_browser()
 	return std::string(utils::bridged::get_default_browser());
 }
 
+std::string utils::md5hash(const std::string& input)
+{
+	return std::string(utils::bridged::md5hash(input));
+}
+
 std::string utils::program_version()
 {
 	return std::string(utils::bridged::program_version());
