@@ -53,6 +53,7 @@ extern "C" {
 #include "urlview.h"
 #include "urlviewformaction.h"
 #include "utils.h"
+#include "searchresultslistformaction.h"
 
 namespace {
 bool ctrl_c_hit = false;
@@ -242,6 +243,14 @@ int View::run()
 std::string View::run_modal(std::shared_ptr<FormAction> f,
 	const std::string& value)
 {
+	// Modal dialogs should not allow changing to a different dialog (except by
+	// closing the modal dialog)
+	const std::set<Operation> ignoredOperations = {
+		OP_VIEWDIALOGS,
+		OP_NEXTDIALOG,
+		OP_PREVDIALOG,
+	};
+
 	f->init();
 	unsigned int stacksize = formaction_stack.size();
 
@@ -275,6 +284,11 @@ std::string View::run_modal(std::shared_ptr<FormAction> f,
 			continue;
 		}
 
+		if (ignoredOperations.count(op)) {
+			status_line.show_message(_("Operation ignored in modal dialog"));
+			continue;
+		}
+
 		fa->process_op(op);
 	}
 
@@ -431,18 +445,21 @@ void View::push_searchresult(std::shared_ptr<RssFeed> feed,
 {
 	assert(feed != nullptr);
 	LOG(Level::DEBUG, "View::push_searchresult: pushing search result");
-
 	if (feed->total_item_count() > 0) {
-		auto searchresult = std::make_shared<ItemListFormAction>(
-				this, itemlist_str, rsscache, filters, cfg, rxman);
-		searchresult->set_feed(feed);
-		searchresult->set_show_searchresult(true);
-		searchresult->set_searchphrase(phrase);
-		apply_colors(searchresult);
-		searchresult->set_parent_formaction(get_current_formaction());
-		searchresult->init();
-		formaction_stack.push_back(searchresult);
-		current_formaction = formaction_stack_size() - 1;
+		if (this->get_current_formaction()->id() != "searchresultslist") {
+			auto searchresult = std::make_shared<SearchResultsListFormAction>(
+					this, itemlist_str, rsscache, filters, cfg, rxman);
+			apply_colors(searchresult);
+			searchresult->set_parent_formaction(get_current_formaction());
+			searchresult->add_to_history(feed, phrase);
+			searchresult->init();
+			formaction_stack.push_back(searchresult);
+			current_formaction = formaction_stack_size() - 1;
+		} else {
+			auto searchresult = std::static_pointer_cast<SearchResultsListFormAction>
+				(this->get_current_formaction());
+			searchresult->add_to_history(feed, phrase);
+		}
 	} else {
 		status_line.show_error(_("Error: feed contains no items!"));
 	}
@@ -467,7 +484,6 @@ std::shared_ptr<ItemListFormAction> View::push_itemlist(
 		auto itemlist = std::make_shared<ItemListFormAction>(
 				this, itemlist_str, rsscache, filters, cfg, rxman);
 		itemlist->set_feed(feed);
-		itemlist->set_show_searchresult(false);
 		apply_colors(itemlist);
 		itemlist->set_parent_formaction(get_current_formaction());
 		itemlist->init();
