@@ -474,6 +474,26 @@ TEST_CASE("tags still work inside <pre>", "[HtmlRenderer]")
 	REQUIRE(links.size() == 0);
 }
 
+TEST_CASE("line breaks are preserved in tags inside <pre>", "[HtmlRenderer]")
+{
+	HtmlRenderer r;
+
+	const std::string input =
+		"<pre><span>\n\n\n"
+		"very cool</span><span>very cool indeed\n\n\n"
+		"</span></pre>";
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	REQUIRE_NOTHROW(r.render(input, lines, links, url));
+	REQUIRE(lines.size() == 4);
+	REQUIRE(lines[0] == p(LineType::softwrappable, ""));
+	REQUIRE(lines[1] == p(LineType::softwrappable, ""));
+	REQUIRE(lines[2] == p(LineType::softwrappable, "very coolvery cool indeed"));
+	REQUIRE(lines[3] == p(LineType::softwrappable, ""));
+	REQUIRE(links.size() == 0);
+}
+
 TEST_CASE("<img> results in a placeholder and a link", "[HtmlRenderer]")
 {
 	HtmlRenderer r;
@@ -1646,7 +1666,8 @@ TEST_CASE("Skips contents of <script> tags", "[HtmlRenderer]")
 	std::vector<LinkPair> links;
 
 	std::ifstream input_file("data/1300-reproducer.html");
-	const auto input = std::string{std::istreambuf_iterator<char>(input_file), std::istreambuf_iterator<char>()};
+	std::string input;
+	input_file >> input;
 
 	rnd.render(input, lines, links, "");
 
@@ -1685,3 +1706,17 @@ TEST_CASE("<div> is always rendered on a new line", "[HtmlRenderer]")
 	REQUIRE(lines[8] == p(LineType::wrappable, "hehe"));
 	REQUIRE(links.size() == 0);
 }
+
+TEST_CASE("HtmlRenderer does not crash on extra closing OL/UL tags", "[HtmlRenderer]")
+{
+	// This is a regression test for https://github.com/newsboat/newsboat/issues/1974
+
+	HtmlRenderer rnd;
+	std::vector<std::pair<LineType, std::string>> lines;
+	std::vector<LinkPair> links;
+
+	const std::string input =
+		"<ul><li>Double closed list</li></ul></ul><ol><li>Other double closed list</li></ol></ol><ul><li>Test</li></ul>";
+
+	rnd.render(input, lines, links, "");
+}
